@@ -128,6 +128,12 @@ public class NomenclatureIntegrationTest {
 		checkName(name, expectedInchi);
 	}
 	
+	@ParameterizedTest
+	@CsvFileSource(resources = "hwRings.txt", delimiter='\t')
+	public void testHwRingNomenclature(String name, String expectedInchi) {
+		checkName(name, expectedInchi);
+	}
+	
 	@ParameterizedTest
 	@CsvFileSource(resources = "inorganics.txt", delimiter='\t')
 	public void testInorganicNomenclature(String name, String expectedInchi) {
